==> phplist-2.10.5p0.tgz: lists/admin/lan/en/spageedit.php <==
<?php

$lan = array(
'General Information' => 'General Information',
'Title' => 'Title',
'Title of this set of lists' => 'Title of this set of lists',
'Please indicate how often you want to receive messages' => 'Please indicate how often you want to receive messages',
'Don\'t offer choice, default to <b>text</b>' => 'Don\'t offer choice, default to <b>text</b>',
'Don\'t offer choice, default to <b>HTML</b>' => 'Don\'t offer choice, default to <b>HTML</b>',
'Don\'t display email confirmation' => 'Don\'t display email confirmation',
'Intro' => 'Intro',
'Header' => 'Header',
'Footer' => 'Footer',
'Thank you page' => 'Thank you page',
'Text for Button' => 'Text for Button',
'HTML Email choice' => 'HTML Email choice',
'Offer checkbox for text' => 'Offer checkbox for text',
'Offer checkbox for HTML' => 'Offer checkbox for HTML',
'Radio buttons, default to text' => 'Radio buttons, default to text',
'Radio buttons, default to HTML' => 'Radio buttons, default to HTML',
'Display Email confirmation' => 'Display Email confirmation',
'Display email confirmation' => 'Display email confirmation',
'Message they receive when they subscribe' => 'Message they receive when they subscribe',
'Message they receive when they confirm their subscription' => 'Message they receive when they confirm their subscription',
'Subject' => 'Subject',
'Message' => 'Message',
'Select the attributes to use' => 'Select the attributes to use',
'No lists available, please create one first' => 'No lists available, please create one first',
'Attribute' => 'Attribute',
'Check this box to use this attribute in the page' => 'Check this box to use this attribute in the page',
'Type' => 'Type',
'Default Value' => 'Default Value',
'Order of Listing' => 'Order of Listing',
'Is this attribute required?' => 'Is this attribute required?',
'Attribute' => 'Attribute',
'Check this box to use this attribute in the page' => 'Check this box to use this attribute in the page',
'Type' => 'Type',
'Default Value' => 'Default Value',
'Order of Listing' => 'Order of Listing',
'Is this attribute required?' => 'Is this attribute required?',
'RSS settings' => 'RSS settings',
'Intro Text' => 'Intro Text',
'Offer option to receive' => 'Offer option to receive',
'Daily' => 'Daily',
'default' => 'default',
'Offer option to receive' => 'Offer option to receive',
'Weekly' => 'Weekly',
'default' => 'default',
'Offer option to receive' => 'Offer option to receive',
'Monthly' => 'Monthly',
'default' => 'default',
'Select the lists to offer' => 'Select the lists to offer',
'Owner' => 'Owner',
'Save Changes' => 'Save Changes',
'Save and Activate' => 'Save and Activate',
'Save and Deactivate' => 'Save and Deactivate',

);
?>

==> phplist-2.10.14p1.tgz: lists/admin/lan/en/spageedit.php <==
<?php

$lan = array(

'General Information' => 'General Information',
'Title' => 'Title',
'Title of this set of lists' => 'Title of this set of lists',
'Don\'t offer choice, default to <b>text</b>' => 'Don\'t offer choice, default to <b>text</b>',
'Don\'t offer choice, default to <b>HTML</b>' => 'Don\'t offer choice, default to <b>HTML</b>',
'Don\'t display email confirmation' => 'Don\'t display email confirmation',
'Intro' => 'Intro',
'Footer' => 'Footer',
'Thank you page' => 'Thank you page',
'Text for Button' => 'Text for Button',
'HTML Email choice' => 'HTML Email choice',
'Offer checkbox for text' => 'Offer checkbox for text',
'Offer checkbox for HTML' => 'Offer checkbox for HTML',
'Radio buttons, default to text' => 'Radio buttons, default to text',
'Radio buttons, default to HTML' => 'Radio buttons, default to HTML',
'Display Email confirmation' => 'Display Email confirmation',
'Display email confirmation' => 'Display email confirmation',
'Message they receive when they subscribe' => 'Message they receive when they subscribe',
'Message they receive when they confirm their subscription' => 'Message they receive when they confirm their subscription',
'Select the attributes to use' => 'Select the attributes to use',
'No lists available, please create one first' => 'No lists available, please create one first',
'Attribute' => 'Attribute',
'Check this box to use this attribute in the page' => 'Check this box to use this attribute in the page',
'Default Value' => 'Default Value',
'Order of Listing' => 'Order of Listing',
'Is this attribute required?' => 'Is this attribute required?',
'RSS settings' => 'RSS settings',
'Intro Text' => 'Intro Text',
'Offer option to receive' => 'Offer option to receive',
'Select the lists to offer' => 'Select the lists to offer',
'Save and Activate' => 'Save and Activate',
'Save and Deactivate' => 'Save and Deactivate',
'Language file to use' => 'Language file to use',
'rss settings' => 'rss settings',
'<font color=#A704FF>Daily</font>' => '<font color=#A704FF>Daily</font>',
'<font color=#A704FF>Weekly</font>' => '<font color=#A704FF>Weekly</font>',
'<font color=#A704FF>Monthly</font>' => '<font color=#A704FF>Monthly</font>',
);
?>
